import React from 'react';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
declare type TabVariant = 'inside' | 'outside';
interface TabItem<T> {
    readonly value: T;
    readonly label: string;
    readonly disabled?: boolean;
}
export interface CardTabsProps<T> extends Omit<BaseProps, 'onChange'> {
    /**
     * Current selected tab, matching a `value` from options
     */
    readonly value: T;
    /**
     * Array with object that contain `value`, `label`, and optional `disabled`
     */
    readonly options: ReadonlyArray<TabItem<T>>;
    /**
     * Tab change callback, called with the `value` from the selected options
     */
    readonly onChange: (value: T) => void;
    /**
     * Tab variant. You need to select `inside` or `outside`
     */
    readonly variant: TabVariant;
    /**
     * Decides whether the active tab should have a background
     */
    readonly hasBackground?: boolean;
}
export declare function CardTabs<T>({ value, options, onChange, variant, hasBackground, ...props }: CardTabsProps<T>): JSX.Element;
export {};
