"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Section = exports.ScrollSection = exports.EdgeToEdgeSection = exports.DialogMainSection = exports.CenteredSection = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _designparams = require("../../designparams");

var _padding = require("./padding");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * DialogMainSection
 *
 * Simple div to base other sections on. It comes with a default padding to make
 * sure this isn't left out of anything put in the dialog body. Sections can be
 * used inside the content and have edgeless variants counteracting the padding.
 */
var BaseSection = _styledComponents.default.div.withConfig({
  displayName: "DialogMainSection__BaseSection",
  componentId: "sc-bggxfy-0"
})(["position:relative;max-height:100%;color:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.text01();
});

var Section = (0, _styledComponents.default)(BaseSection).withConfig({
  displayName: "DialogMainSection__Section",
  componentId: "sc-bggxfy-1"
})(["padding:0 ", ";"], _padding.DIALOG_PADDING);
/**
 * Provides a container that horizontally centers its contents
 */

exports.Section = Section;
var CenteredSection = (0, _styledComponents.default)(Section).withConfig({
  displayName: "DialogMainSection__CenteredSection",
  componentId: "sc-bggxfy-2"
})(["align-items:center;"]);
/**
 * Provides a container that removes the left and right padding
 * provided by `Content`, using a negative margin
 */

exports.CenteredSection = CenteredSection;
var EdgeToEdgeSection = (0, _styledComponents.default)(Section).withConfig({
  displayName: "DialogMainSection__EdgeToEdgeSection",
  componentId: "sc-bggxfy-3"
})(["margin:0 -", ";"], _padding.DIALOG_PADDING);
/**
 * Scrollable section
 */

exports.EdgeToEdgeSection = EdgeToEdgeSection;
var ScrollContainer = (0, _styledComponents.default)(Section).withConfig({
  displayName: "DialogMainSection__ScrollContainer",
  componentId: "sc-bggxfy-4"
})(["overflow-y:auto;overflow-y:overlay;"]);

var ScrollSection = _ref2 => {
  var {
    className,
    maxHeight,
    scrollRef,
    children
  } = _ref2;
  return /*#__PURE__*/_react.default.createElement(ScrollContainer, {
    className: className,
    ref: scrollRef,
    style: {
      maxHeight
    }
  }, children);
};

exports.ScrollSection = ScrollSection;
var DialogMainSection = (0, _styledComponents.default)(ScrollSection).withConfig({
  displayName: "DialogMainSection",
  componentId: "sc-bggxfy-5"
})(["padding-top:", ";padding-bottom:48px;"], _ref3 => {
  var {
    hasHeader
  } = _ref3;
  return hasHeader ? '0' : _designparams.spacing.extraLarge;
});
exports.DialogMainSection = DialogMainSection;