"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TimeInputField = exports.TimeInput = exports.DurationInputField = exports.DurationInput = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _designparams = require("../designparams");

var _Input = require("./Input");

var _Select = require("../Select");

var _withField = require("../utils/withField");

var _excluded = ["value", "onChange", "hour12", "hour12MeridiemLabels"],
    _excluded2 = ["value", "onChange", "format"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var TimeFormat;

(function (TimeFormat) {
  TimeFormat["AM"] = "AM";
  TimeFormat["PM"] = "PM";
})(TimeFormat || (TimeFormat = {}));

var Format;

(function (Format) {
  Format["HHMMSS"] = "hh:mm:ss";
  Format["HHMM"] = "hh:mm";
  Format["MMSS"] = "mm:ss";
  Format["HH"] = "hh";
  Format["MM"] = "mm";
  Format["SS"] = "ss";
})(Format || (Format = {}));

var BACKSPACE_KEY = 'Backspace';
var DELETE_KEY = 'Delete';

var TimeContainer = _styledComponents.default.div.withConfig({
  displayName: "TimeInput__TimeContainer",
  componentId: "sc-2idmtc-0"
})(["display:grid;grid-template-columns:", ";grid-column-gap:", ";align-items:end;"], _ref => {
  var {
    hour12
  } = _ref;
  return hour12 ? "72px 64px" : "144px";
}, _designparams.spacing.medium);

/**
 * Time input only has a max length of two numbers so maximum number is 99
 */
var MAX_INPUT_VALUE = 100;
/**
 * Used to control the cursors position when state updates.
 */

var inputPos = 0;

var isNewValuesValid = _ref2 => {
  var {
    hour,
    minute,
    second
  } = _ref2;
  var hourValidate = hour !== null && hour !== void 0 ? hour : 0;
  var minuteValidate = minute !== null && minute !== void 0 ? minute : 0;
  var secondValidate = second !== null && second !== void 0 ? second : 0;
  return hourValidate < 24 && minuteValidate < 60 && secondValidate < 60;
};

var isNewDurationValuesValid = _ref3 => {
  var {
    hour,
    minute,
    second
  } = _ref3;
  var maxMinute = 60;
  var maxSecond = 60;
  var maxHour = 100;

  if (hour === undefined) {
    maxMinute = MAX_INPUT_VALUE;
  }

  if (minute === undefined) {
    maxSecond = MAX_INPUT_VALUE;
  }

  var hourValidate = hour !== null && hour !== void 0 ? hour : 0;
  var minuteValidate = minute !== null && minute !== void 0 ? minute : 0;
  var secondValidate = second !== null && second !== void 0 ? second : 0;
  return hourValidate < maxHour && minuteValidate < maxMinute && secondValidate < maxSecond;
};

var CursorPositions;
/**
 * Gets the next caret position
 * @param position Current caret position
 * @param backspace If backspace was pressed
 */

(function (CursorPositions) {
  CursorPositions[CursorPositions["BeforeFirstColon"] = 2] = "BeforeFirstColon";
  CursorPositions[CursorPositions["BeforeSecondColon"] = 5] = "BeforeSecondColon";
  CursorPositions[CursorPositions["AfterFirstColon"] = 3] = "AfterFirstColon";
  CursorPositions[CursorPositions["AfterSecondColon"] = 6] = "AfterSecondColon";
})(CursorPositions || (CursorPositions = {}));

var getTargetPos = (position, backspace) => {
  if (!backspace) {
    switch (position) {
      case CursorPositions.BeforeFirstColon:
      case CursorPositions.BeforeSecondColon:
        return position + 1;

      default:
        return position;
    }
  }

  switch (position) {
    case CursorPositions.AfterFirstColon:
    case CursorPositions.AfterSecondColon:
      return position - 2;

    default:
      return position - 1;
  }
};
/**
 * Moves the cursor one extra position if next to a colon
 *
 * @param position
 * @param backspace
 */


var moveCursor = (position, backspace) => {
  if (!backspace) {
    switch (position) {
      case CursorPositions.BeforeFirstColon:
      case CursorPositions.BeforeSecondColon:
        return position + 1;

      default:
        return position;
    }
  }

  switch (position) {
    case CursorPositions.AfterFirstColon:
    case CursorPositions.AfterSecondColon:
      return position - 1;

    default:
      return position;
  }
};

var convertToTwentyFour = (hour, ampm) => {
  if (hour === 0) {
    // 0 does not exist on AM/PM so it can be converted to 1 instead.
    hour = 1;
  }

  if (ampm === TimeFormat.AM) {
    return hour === 12 ? 0 : hour;
  }

  return hour === 12 ? hour : hour + 12;
};

var SECONDS_PER_HOUR = 3600;
var SECONDS_PER_MINUTE = 60;

var parseSecondsToFormat = (sec, format) => {
  var hour;
  var minute;
  var second;

  switch (format) {
    case Format.HHMMSS:
      hour = Math.floor(sec / SECONDS_PER_HOUR);
      sec %= SECONDS_PER_HOUR;
      minute = Math.floor(sec % SECONDS_PER_HOUR / SECONDS_PER_MINUTE);
      second = sec % SECONDS_PER_MINUTE;
      break;

    case Format.HHMM:
      hour = Math.floor(sec / SECONDS_PER_HOUR);
      sec %= SECONDS_PER_HOUR;
      minute = Math.floor(sec % SECONDS_PER_HOUR / SECONDS_PER_MINUTE);
      break;

    case Format.MMSS:
      minute = Math.floor(sec / SECONDS_PER_MINUTE);
      second = sec % SECONDS_PER_MINUTE;
      break;

    case Format.HH:
      hour = Math.floor(sec / SECONDS_PER_HOUR);
      break;

    case Format.MM:
      minute = Math.floor(sec / SECONDS_PER_MINUTE);
      break;

    case Format.SS:
      second = sec;
      break;

    default:
  }

  return {
    hour,
    minute,
    second
  };
};

var parseToAMPM = hour => {
  if (hour === undefined) {
    return undefined;
  }

  var hourAMPM = parseInt(hour) % 12;
  return (hourAMPM === 0 ? 12 : hourAMPM).toString();
};

var getKeyCodeValue = key => {
  var backspace = key === BACKSPACE_KEY;
  return {
    keyValue: backspace || key === DELETE_KEY ? '0' : key,
    backspace
  };
};

/**
 * Time input component
 *
 * The time input uses a text input box to
 * write time, the input forces the user to enter
 * in a specific format e.g. (hh:mm:ss).
 *
 * When variant `hour12` is `false` the time input will act as a 24 hour input.
 *
 * When property `hour12` is `true`, the input is
 * postfixed with am/pm, and the hours can only go
 * from 01 to 12, there is also a select besides the input component
 * that lets the user to choose between AM and PM.
 *
 * Duration input component (DurationInput)
 *
 * Is a variant of TimeInput but the highest time unit
 * in the input are not limited in value (can go up to max 99).
 */
var TimeInput = _ref4 => {
  var {
    value,
    onChange,
    hour12 = false,
    hour12MeridiemLabels = {
      am: 'AM',
      pm: 'PM'
    }
  } = _ref4,
      props = _objectWithoutProperties(_ref4, _excluded);

  var inputElement = /*#__PURE__*/_react.default.createRef();

  var {
    hour,
    minute,
    second
  } = (0, _react.useMemo)(() => value, [value]);
  var inputValue = (0, _react.useMemo)(() => {
    var _parseToAMPM;

    var hourString = hour12 ? (_parseToAMPM = parseToAMPM(hour === null || hour === void 0 ? void 0 : hour.toString())) === null || _parseToAMPM === void 0 ? void 0 : _parseToAMPM.padStart(2, '0') : hour === null || hour === void 0 ? void 0 : hour.toString().padStart(2, '0');
    var minuteString = minute === null || minute === void 0 ? void 0 : minute.toString().padStart(2, '0');
    var secondsString = second === null || second === void 0 ? void 0 : second.toString().padStart(2, '0');
    return [hourString, minuteString, secondsString].filter(stringValue => stringValue !== undefined).join(':');
  }, [hour, minute, second, hour12]);
  var timeFormat = (0, _react.useMemo)(() => hour !== undefined && hour < 12 ? TimeFormat.AM : TimeFormat.PM, [hour]);
  var onTimeFormatSelect = (0, _react.useCallback)(newTimeFormat => {
    var newCallbackValues = inputValue.split(':').reduce((acc, v) => {
      if (hour !== undefined && acc.hour === undefined) {
        acc = {
          hour: convertToTwentyFour(parseInt(v), newTimeFormat)
        };
      } else if (minute !== undefined && acc.minute === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          minute: parseInt(v)
        });
      } else if (second !== undefined && acc.second === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          second: parseInt(v)
        });
      }

      return acc;
    }, {});
    onChange(newCallbackValues);
  }, [inputValue, onChange, hour, minute, second]);
  var ampmOptions = (0, _react.useMemo)(() => [{
    value: TimeFormat.AM,
    label: hour12MeridiemLabels.am
  }, {
    value: TimeFormat.PM,
    label: hour12MeridiemLabels.pm
  }], [hour12MeridiemLabels]);
  var setCursorPosition = (0, _react.useCallback)(newPos => {
    if (inputElement.current !== null && document.activeElement === inputElement.current) {
      inputElement.current.setSelectionRange(newPos, newPos);
    }
  }, [inputElement]);
  (0, _react.useLayoutEffect)(() => setCursorPosition(inputPos), [inputValue, setCursorPosition]);
  var onKeyDown = (0, _react.useCallback)(event => {
    var _currentTarget$select;

    var {
      keyValue,
      backspace
    } = getKeyCodeValue(event.key); // If the key pressed is not a number

    if (!/^\d$/.test(keyValue)) {
      return;
    } // Find input position and get target position for the new value.


    event.preventDefault();
    var {
      currentTarget
    } = event;
    var currentValue = currentTarget.value;
    inputPos = getTargetPos((_currentTarget$select = currentTarget.selectionStart) !== null && _currentTarget$select !== void 0 ? _currentTarget$select : currentValue.length, backspace); // If at last position of input, no need write anything just return

    if (currentValue.length <= inputPos || inputPos === -1) {
      return;
    }

    var newInputValue = "".concat(currentValue.substring(0, inputPos)).concat(keyValue).concat(currentValue.substring(inputPos + 1, currentValue.length));
    var newCallbackValues = newInputValue.split(':').reduce((acc, v) => {
      var number = parseInt(v);

      if (number >= MAX_INPUT_VALUE) {
        number = MAX_INPUT_VALUE - 1;
      }

      if (hour !== undefined && acc.hour === undefined) {
        acc = {
          hour: hour12 ? convertToTwentyFour(number, timeFormat) : number
        };
      } else if (minute !== undefined && acc.minute === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          minute: number
        });
      } else if (second !== undefined && acc.second === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          second: number
        });
      }

      return acc;
    }, {});

    if (!isNewValuesValid(newCallbackValues)) {
      return;
    } // If we pressed backspace we want to stay at current position we have else move 1 forward


    inputPos += backspace ? 0 : 1;
    inputPos = moveCursor(inputPos, backspace); // If the value is the same as before we need to set the cursors position
    // because useEffect does not run.

    if (newInputValue === inputValue) {
      setCursorPosition(inputPos);
    }

    onChange(newCallbackValues);
  }, [onChange, inputValue, hour, minute, second, setCursorPosition, hour12, timeFormat]);
  return /*#__PURE__*/_react.default.createElement(TimeContainer, {
    hour12: hour12
  }, /*#__PURE__*/_react.default.createElement(_Input.TextInput, _extends({
    value: inputValue,
    inputRef: inputElement,
    onKeyDown: onKeyDown
  }, props)), hour12 && hour !== undefined ? /*#__PURE__*/_react.default.createElement(_Select.Select, {
    variant: "transparent",
    value: timeFormat,
    options: ampmOptions,
    onChange: onTimeFormatSelect,
    compact: props.compact
  }) : null);
};

exports.TimeInput = TimeInput;

/**
 * Duration input component
 *
 * Is a variant of TimeInput but the highest time unit
 * in the input are not limited in value (can go up to max 99).
 */
var DurationInput = _ref5 => {
  var {
    value,
    onChange,
    format
  } = _ref5,
      props = _objectWithoutProperties(_ref5, _excluded2);

  var inputElement = /*#__PURE__*/_react.default.createRef();

  var {
    hour,
    minute,
    second
  } = (0, _react.useMemo)(() => parseSecondsToFormat(value, format), [value, format]);
  var inputValue = (0, _react.useMemo)(() => {
    var hourString = hour === null || hour === void 0 ? void 0 : hour.toString().padStart(2, '0');
    var minuteString = minute === null || minute === void 0 ? void 0 : minute.toString().padStart(2, '0');
    var secondsString = second === null || second === void 0 ? void 0 : second.toString().padStart(2, '0');
    return [hourString, minuteString, secondsString].filter(stringValue => stringValue !== undefined).join(':');
  }, [hour, minute, second]);
  var setCursorPosition = (0, _react.useCallback)(newPos => {
    if (inputElement.current !== null && document.activeElement === inputElement.current) {
      inputElement.current.setSelectionRange(newPos, newPos);
    }
  }, [inputElement]);
  (0, _react.useLayoutEffect)(() => setCursorPosition(inputPos), [inputValue, setCursorPosition]);
  var onKeyDown = (0, _react.useCallback)(event => {
    var _currentTarget$select2, _newCallbackValues$ho, _newCallbackValues$mi, _newCallbackValues$se;

    var {
      keyValue,
      backspace
    } = getKeyCodeValue(event.key); // If the key pressed is not a number

    if (!/^\d$/.test(keyValue)) {
      return;
    } // Find input position and get target position for the new value.


    event.preventDefault();
    var {
      currentTarget
    } = event;
    var currentValue = currentTarget.value;
    inputPos = getTargetPos((_currentTarget$select2 = currentTarget.selectionStart) !== null && _currentTarget$select2 !== void 0 ? _currentTarget$select2 : currentValue.length, backspace); // If at last position of input, or backspace at first position

    if (currentValue.length <= inputPos || inputPos === -1) {
      // no need write anything just return
      return;
    }

    var newInputValue = "".concat(currentValue.substring(0, inputPos)).concat(keyValue).concat(currentValue.substring(inputPos + 1, currentValue.length));
    var newCallbackValues = newInputValue.split(':').reduce((acc, v) => {
      var number = parseInt(v);

      if (number >= MAX_INPUT_VALUE) {
        number = MAX_INPUT_VALUE - 1;
      }

      if (hour !== undefined && acc.hour === undefined) {
        acc = {
          hour: number
        };
      } else if (minute !== undefined && acc.minute === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          minute: number
        });
      } else if (second !== undefined && acc.second === undefined) {
        acc = _objectSpread(_objectSpread({}, acc), {}, {
          second: number
        });
      }

      return acc;
    }, {});

    if (!isNewDurationValuesValid(newCallbackValues)) {
      return;
    } // If we pressed backspace we want to stay at current position we have else move 1 forward


    inputPos += backspace ? 0 : 1;
    inputPos = moveCursor(inputPos, backspace); // If the value is the same as before we need to set the cursors position
    // because useEffect does not run.

    if (newInputValue === inputValue) {
      setCursorPosition(inputPos);
    }

    onChange(((_newCallbackValues$ho = newCallbackValues.hour) !== null && _newCallbackValues$ho !== void 0 ? _newCallbackValues$ho : 0) * SECONDS_PER_HOUR + ((_newCallbackValues$mi = newCallbackValues.minute) !== null && _newCallbackValues$mi !== void 0 ? _newCallbackValues$mi : 0) * SECONDS_PER_MINUTE + ((_newCallbackValues$se = newCallbackValues.second) !== null && _newCallbackValues$se !== void 0 ? _newCallbackValues$se : 0));
  }, [onChange, inputValue, hour, minute, second, setCursorPosition]);
  return /*#__PURE__*/_react.default.createElement(TimeContainer, {
    hour12: false
  }, /*#__PURE__*/_react.default.createElement(_Input.TextInput, _extends({
    value: inputValue,
    inputRef: inputElement,
    onKeyDown: onKeyDown
  }, props)));
};

exports.DurationInput = DurationInput;
var TimeInputField = (0, _withField.withField)(TimeInput);
exports.TimeInputField = TimeInputField;
var DurationInputField = (0, _withField.withField)(DurationInput);
exports.DurationInputField = DurationInputField;