"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useOnScrollEffect = exports.useOnResizeParentEffect = exports.useOnResizeEffect = exports.anchorPosition = void 0;

var _react = require("react");

// Reposition on scroll
var useOnScrollEffect = (anchorEl, onScroll) => {
  (0, _react.useLayoutEffect)(() => {
    if (anchorEl === null) {
      return undefined;
    }

    var parentEl = anchorEl.parentElement;
    var scrollableParents = [];

    while (parentEl !== null) {
      if (parentEl.scrollHeight > parentEl.clientHeight) {
        scrollableParents.push(parentEl);
      }

      parentEl = parentEl.parentElement;
    }

    scrollableParents.forEach(parent => {
      parent.addEventListener('scroll', onScroll);
    });
    window.addEventListener('scroll', onScroll);
    return () => {
      scrollableParents.forEach(parent => {
        parent.removeEventListener('scroll', onScroll);
      });
      window.removeEventListener('scroll', onScroll);
    };
  }, [onScroll, anchorEl]);
}; // Reposition on resize


exports.useOnScrollEffect = useOnScrollEffect;

var useOnResizeParentEffect = (element, onResize) => {
  (0, _react.useLayoutEffect)(() => {
    if (element === null) {
      return undefined;
    }

    var parentEl = element.parentElement;
    var observer = new window.ResizeObserver(onResize);

    while (parentEl !== null) {
      observer.observe(parentEl);
      parentEl = parentEl.parentElement;
    }

    return () => observer.disconnect();
  }, [onResize, element]);
};

exports.useOnResizeParentEffect = useOnResizeParentEffect;

var useOnResizeEffect = (element, onResize) => {
  (0, _react.useLayoutEffect)(() => {
    if (element === null) {
      return undefined;
    }

    var observer = new window.ResizeObserver(onResize);
    observer.observe(element);
    return () => observer.disconnect();
  }, [onResize, element]);
};

exports.useOnResizeEffect = useOnResizeEffect;

var anchorPosition = (anchorEl, popOverContainerEl, _ref) => {
  var {
    horizontalPosition = 'left',
    horizontalAlignment = 'left',
    verticalPosition = 'bottom',
    verticalAlignment = 'top'
  } = _ref;
  // 🎓 Set up default positioning
  var anchorBBox = anchorEl.getBoundingClientRect();
  var {
    top,
    left,
    bottom,
    right,
    width,
    height
  } = anchorBBox; // Ignore invisible anchor, this might happen when the anchor's
  // visibility changes with e.g. display = 'none', in which case the
  // popover will get the wrong position.

  if (width === 0 && height === 0) {
    return;
  }

  var anchorHPos = {
    left,
    right,
    center: (left + right) / 2
  };
  var anchorVPos = {
    top,
    bottom,
    center: (top + bottom) / 2
  };
  var popOverBBox = popOverContainerEl.getBoundingClientRect();
  var popOverHOffset = {
    left: 0,
    right: -popOverBBox.width,
    center: -popOverBBox.width / 2
  };
  var popOverVOffset = {
    top: 0,
    bottom: -popOverBBox.height,
    center: -popOverBBox.height / 2
  };
  var popOverLeft = anchorHPos[horizontalPosition] + popOverHOffset[horizontalAlignment];
  var popOverTop = anchorVPos[verticalPosition] + popOverVOffset[verticalAlignment]; // 🧚 Automagically keep the pop-over within the document boundaries,
  // by repositioning it if it would overflow.

  var {
    clientHeight,
    clientWidth
  } = document.documentElement;
  var popOverVOverflow = clientHeight - (popOverTop + popOverBBox.height);
  var popOverHOverflow = clientWidth - (popOverLeft + popOverBBox.width);

  if (popOverVOverflow < 0) {
    popOverTop = popOverTop + popOverVOverflow;
  }

  if (popOverHOverflow < 0) {
    popOverLeft = popOverLeft + popOverHOverflow;
  } // Set final positioning on pop-over's style


  popOverContainerEl.style.top = "".concat(popOverTop, "px");
  popOverContainerEl.style.left = "".concat(popOverLeft, "px");
};

exports.anchorPosition = anchorPosition;